@@ -1,4 +1,3 @@
-from numba import float64, int64, boolean, types
 
 class InitialWaterContent:
     """
@@ -18,8 +17,6 @@ class InitialWaterContent:
 
     def __init__(self, wc_type="Prop", method="Layer", depth_layer=[1], value=["FC"]):
 
-        assert len(depth_layer) == len(value)
-
         self.wc_type = wc_type
         self.method = method
         self.depth_layer = depth_layer
