@@ -1,27 +1,15 @@
 import numpy as np
 
-from numba import njit, f8, i8, b1
-from numba.pycc import CC
-
-try:
-    from ..entities.crop import CropStructNT_type_sig
-    from ..entities.waterStressCoefficients import KswNT_type_sig
-except:
-    from entities.crop import CropStructNT_type_sig
-    from entities.waterStressCoefficients import KswNT_type_sig
+from ..entities.crop import Crop
+from ..entities.waterStressCoefficients import Ksw
 
 from typing import TYPE_CHECKING, Tuple
 
 if TYPE_CHECKING:
     # Important: classes are only imported when types are checked, not in production.
-    from aquacrop.entities.crop import CropStructNT
-    from entities.waterStressCoefficients import KswNT
+    from aquacrop.entities.crop import Crop
+    from entities.waterStressCoefficients import Ksw
 
-# temporary name for compiled module
-cc = CC("solution_HIadj_post_anthesis")
-
-
-@cc.export("HIadj_post_anthesis", (i8,f8,f8,i8,f8,f8,f8,f8,CropStructNT_type_sig,KswNT_type_sig,))
 def HIadj_post_anthesis(
     NewCond_DelayedCDs: int,
     NewCond_sCor1: float,
@@ -31,8 +19,8 @@ def HIadj_post_anthesis(
     NewCond_CC: float,
     NewCond_fpost_upp: float,
     NewCond_fpost_dwn: float,
-    Crop: "CropStructNT", 
-    Ksw: "KswNT",
+    Crop: "Crop", 
+    Ksw: "Ksw",
     ) -> Tuple[float, float, float, float, float]:
     """
     Function to calculate adjustment to harvest index for post-anthesis water
@@ -135,6 +123,3 @@ def HIadj_post_anthesis(
             NewCond_fpost_upp,
             NewCond_fpost_dwn,
             NewCond_Fpost)
-
-if __name__ == "__main__":
-    cc.compile()
